[![CircleCI](https://circleci.com/gh/digitalfabrik/lunes-cms.svg?style=shield)](https://circleci.com/gh/digitalfabrik/lunes-cms)
![Coverage](https://img.shields.io/codeclimate/coverage/digitalfabrik/lunes-cms)
[![Documentation Status](https://readthedocs.org/projects/lunes-cms/badge/?version=latest)](https://lunes-cms.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/github/license/digitalfabrik/lunes-cms)](https://opensource.org/licenses/Apache-2.0)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# Lunes CMS

[![Logo](https://lunes.tuerantuer.org/static/images/logo-lunes.svg)](https://www.lunes.app)

[Lunes - Vocabulary for your profession.](https://www.lunes.app)

This is the content management system for the vocabulary trainer app Lunes, which facilitates migrants to acquire technical and subject-specific vocabulary.

## TL;DR

### Prerequisites

Following packages are required before installing the project (install them with your package manager):

* python3.8 or greater
* python3-pip
* python3-venv
* ffmpeg
* libpq-dev
* [PostgreSQL](https://www.postgresql.org/) database server
* [Apache2](https://docs.djangoproject.com/en/3.2/howto/deployment/wsgi/modwsgi/) server with `mod_wsgi`

### Installation

```
pip install lunes-cms
```

## Documentation

For detailed instructions and the source code reference have a look at our documentation:

### https://lunes-cms.rtfd.io
